;; lines/theme.jl
;; Copyright (C) 2000 Adam Marks <marks@divinia.com>
;; Derived from the mono theme by John Harper.


(defgroup lines "Lines Theme"
  :group appearance)

(defcustom lines:normal-color nil
  "Color of inactive frames (if unset use GTK+ background color)."
  :type (optional color)
  :group (appearance lines)
  :user-level novice
  :after-set after-setting-frame-option)

(defcustom lines:active-color "white"
  "Color of active frames."
  :type color
  :group (appearance lines)
  :user-level novice
  :after-set after-setting-frame-option)

(defcustom lines:width 1
  "Width of frame lines."
  :type number
  :group (appearance lines)
  :user-level novice
  :after-set after-setting-frame-option)

(defcustom lines:offset 0
  "Offset of frame from window."
  :type number
  :group (appearance lines)
  :user-level novice
  :after-set after-setting-frame-option)

(let*

     ((initialised-gtk nil)

     (rebuild (lambda ()
		(when (and (not lines:normal-color)
			   (not initialised-gtk))
		  (setq initialised-gtk t)
		  (require 'gtkrc)
		  (gtkrc-call-after-changed
		   (lambda () (rebuild-frames-with-style 'lines))))
		(rebuild-frames-with-style 'lines)))

     (frame-colors (lambda (w)
		     (list (or (window-get w 'frame-inactive-color)
			       (and (not lines:normal-color)
				    (car gtkrc-background))
			       lines:normal-color)
			   (or (window-get w 'frame-active-color)
			       lines:active-color))))

     (line-width (lambda () lines:width))

     (line-offset (lambda () (- -1 lines:offset)))

     (frame `(((background . ,frame-colors)
	       (left-edge . ,line-offset)
	       (right-edge . ,line-offset)
	       (top-edge . ,line-offset)
	       (height . ,line-width)
           (class . top-border))
	       
	      ((background . ,frame-colors)
	       (left-edge . ,line-offset)
	       (width . ,line-width)
	       (top-edge . ,line-offset)
	       (bottom-edge . ,line-offset)
           (class . left-border))
	       
	      ((background . ,frame-colors)
	       (right-edge . ,line-offset)
	       (width . ,line-width)
	       (top-edge . ,line-offset)
	       (bottom-edge . ,line-offset)
           (class . right-border))
	       
	      ((background . ,frame-colors)
	       (left-edge . ,line-offset)
	       (right-edge . ,line-offset)
	       (bottom-edge . ,line-offset)
	       (height . ,line-width)
           (class . bottom-border)))))

  (add-frame-style 'lines
           (lambda (w type)
             (case type
               ((default) frame)
               ((transient) frame)
               ((shaped) frame)
               ((shaped-transient) frame))))

  
  (rebuild)
  (custom-set-property 'lines:normal-color ':after-set rebuild))

